
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'app_localizations_en.dart';
import 'app_localizations_ja.dart';

/// Callers can lookup localized strings with an instance of AppLocalizations returned
/// by `AppLocalizations.of(context)`.
///
/// Applications need to include `AppLocalizations.delegate()` in their app's
/// localizationDelegates list, and the locales they support in the app's
/// supportedLocales list. For example:
///
/// ```
/// import 'gen/app_localizations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: AppLocalizations.localizationsDelegates,
///   supportedLocales: AppLocalizations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the AppLocalizations.supportedLocales
/// property.
abstract class AppLocalizations {
  AppLocalizations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static AppLocalizations? of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations);
  }

  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('en'),
    Locale('ja')
  ];

  /// No description provided for @appName.
  ///
  /// In en, this message translates to:
  /// **'GithubSearch'**
  String get appName;

  /// No description provided for @error.
  ///
  /// In en, this message translates to:
  /// **'Error'**
  String get error;

  /// No description provided for @errorOccurred.
  ///
  /// In en, this message translates to:
  /// **'An error has occurred.'**
  String get errorOccurred;

  /// No description provided for @forksCount.
  ///
  /// In en, this message translates to:
  /// **'Forks count'**
  String get forksCount;

  /// No description provided for @githubApiExceptionMessageBadRequest.
  ///
  /// In en, this message translates to:
  /// **'Illegal request sent. (400)'**
  String get githubApiExceptionMessageBadRequest;

  /// No description provided for @githubApiExceptionMessageBadCredentials.
  ///
  /// In en, this message translates to:
  /// **'Illegal request sent. (401)'**
  String get githubApiExceptionMessageBadCredentials;

  /// No description provided for @githubApiExceptionMessageMaximumNumberOfLoginAttemptsExceeded.
  ///
  /// In en, this message translates to:
  /// **'Please wait a while and try again. (403)'**
  String get githubApiExceptionMessageMaximumNumberOfLoginAttemptsExceeded;

  /// No description provided for @githubApiExceptionMessageNotFound.
  ///
  /// In en, this message translates to:
  /// **'No data found. (404)'**
  String get githubApiExceptionMessageNotFound;

  /// No description provided for @githubApiExceptionMessageValidationFailed.
  ///
  /// In en, this message translates to:
  /// **'Illegal request sent. (422)'**
  String get githubApiExceptionMessageValidationFailed;

  /// No description provided for @githubApiExceptionMessageServiceUnavailable.
  ///
  /// In en, this message translates to:
  /// **'Please wait a while and try again.  (503)'**
  String get githubApiExceptionMessageServiceUnavailable;

  /// No description provided for @githubApiExceptionMessageUnknown.
  ///
  /// In en, this message translates to:
  /// **'An unknown error has occurred. (-1)'**
  String get githubApiExceptionMessageUnknown;

  /// No description provided for @githubApiExceptionMessageNoInternetConnection.
  ///
  /// In en, this message translates to:
  /// **'Please try again in a good communication environment. (-2)'**
  String get githubApiExceptionMessageNoInternetConnection;

  /// No description provided for @issuesCount.
  ///
  /// In en, this message translates to:
  /// **'Issues count'**
  String get issuesCount;

  /// No description provided for @ownerName.
  ///
  /// In en, this message translates to:
  /// **'Owner name'**
  String get ownerName;

  /// No description provided for @projectLanguage.
  ///
  /// In en, this message translates to:
  /// **'Project language'**
  String get projectLanguage;

  /// No description provided for @repo.
  ///
  /// In en, this message translates to:
  /// **'Repository'**
  String get repo;

  /// No description provided for @repoName.
  ///
  /// In en, this message translates to:
  /// **'Repository name'**
  String get repoName;

  /// No description provided for @starsCount.
  ///
  /// In en, this message translates to:
  /// **'Stars count'**
  String get starsCount;

  /// No description provided for @searchRepos.
  ///
  /// In en, this message translates to:
  /// **'Search repositories'**
  String get searchRepos;

  /// No description provided for @watchersCount.
  ///
  /// In en, this message translates to:
  /// **'Watchers count'**
  String get watchersCount;
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) {
    return SynchronousFuture<AppLocalizations>(lookupAppLocalizations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['en', 'ja'].contains(locale.languageCode);

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

AppLocalizations lookupAppLocalizations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'en': return AppLocalizationsEn();
    case 'ja': return AppLocalizationsJa();
  }

  throw FlutterError(
    'AppLocalizations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
